SAMSum Corpus contains over 16k chat dialogues with manually annotated
summaries.

There are two features:

-   dialogue: text of dialogue.
-   summary: human written summary of the dialogue.
-   id: id of an example.
